package
Version:
v0.0.0-...-a7b3c09
Opens a new window with list of versions in this module.
Published: Apr 18, 2022
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DataDoc struct {
Id string `yaml:"id"`
Version string `yaml:"version"`
Namespace string `yaml:"namespace"`
Modified time.Time `yaml:"modified"`
Template string `yaml:"template"`
Data string `yaml:"content"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.